from fastapi import APIRouter
from pydantic import BaseModel

from fast_microservice.settings.globals import APP_VERSION

router = APIRouter()


class VersionResult(BaseModel):
    """ Version response model. """

    version: str


@router.get("/version", response_model=VersionResult, name="version")
def get_version() -> VersionResult:
    """ Version of the application."""
    return VersionResult(version=APP_VERSION)



#!/usr/bin/env python

"""
inspiration.

* https://github.com/eightBEC/fastapi-ml-skeleton/tree/master/fastapi_skeleton
(APACHE 2.0)
* https://github.com/leosussan/fastapi-gino-arq-uvicorn
(PUBLIC DOMAIN)
"""

from fastapi import FastAPI

from fast_microservice.helpers import MiddlewareWrapper
from fast_microservice.routers import error, heartbeat, versions
from fast_microservice.settings.globals import (
    API_PREFIX,
    APP_NAME,
    APP_VERSION,
    DEBUG,
    SENTRY_DSN,
    SENTRY_ENABLED,
)

ROUTERS = (heartbeat.router, versions.router, error.router)


def get_app() -> FastAPI:
    """ Fastapi App instance. """
    fast_app = FastAPI(title=APP_NAME, version=APP_VERSION, debug=DEBUG)

    for router in ROUTERS:
        fast_app.include_router(router, prefix=API_PREFIX)

    if SENTRY_ENABLED and SENTRY_DSN not in ("None", ""):
        import sentry_sdk
        from sentry_sdk.integrations.asgi import SentryAsgiMiddleware

        sentry_sdk.init(dsn=str(SENTRY_DSN))
        fast_app = MiddlewareWrapper(SentryAsgiMiddleware(fast_app))

    return fast_app


app = get_app()



from fastapi import APIRouter
from pydantic import BaseModel

router = APIRouter()


class HearbeatResult(BaseModel):
    """ Heartbeat response model. """

    is_alive: bool


@router.get("/heartbeat", response_model=HearbeatResult, name="heartbeat")
def get_hearbeat() -> HearbeatResult:
    """ Heartbeat if the service is alive. """
    return HearbeatResult(is_alive=True)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['fast_microservice',
 'fast_microservice.routers',
 'fast_microservice.services',
 'fast_microservice.settings']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML>=5.3.1,<6.0.0',
 'fastapi>=0.63.0,<0.64.0',
 'pydantic>=1.7.3,<2.0.0',
 'python-multipart>=0.0.5,<0.0.6',
 'requests-toolbelt>=0.9.1,<0.10.0',
 'requests>=2.25.1,<3.0.0',
 'sentry-sdk>=0.19.5,<0.20.0',
 'ujson>=4.0.1,<5.0.0',
 'uvicorn>=0.13.2,<0.14.0']

setup_kwargs = {
    'name': 'fast-microservice',
    'version': '0.1.0rc4',
    'description': 'Small Microservice based on FastAPI',
    'long_description': '# fast-microservice\n\n![PyPI](https://img.shields.io/pypi/v/fast-microservice?style=flat-square)\n![GitHub Workflow Status (master)](https://img.shields.io/github/workflow/status/jberends/fast-microservice/Test%20&%20Lint/master?style=flat-square)\n![Coveralls github branch](https://img.shields.io/coveralls/github/jberends/fast-microservice/master?style=flat-square)\n![PyPI - Python Version](https://img.shields.io/pypi/pyversions/fast-microservice?style=flat-square)\n![PyPI - License](https://img.shields.io/pypi/l/fast-microservice?style=flat-square)\n\nSmall Microservice Abased on FastAPI\n\n## Requirements\n\n* Python 3.6.1 or newer\n\n## Installation\n\n```sh\npip install fast-microservice\n```\n\n## Development\n\nThis project uses [poetry](https://poetry.eustace.io/) for packaging and\nmanaging all dependencies and [pre-commit](https://pre-commit.com/) to run\n[flake8](http://flake8.pycqa.org/), [isort](https://pycqa.github.io/isort/),\n[mypy](http://mypy-lang.org/) and [black](https://github.com/python/black).\n\nClone this repository and run\n\n```bash\npoetry install\npoetry run pre-commit install\n```\n\nto create a virtual enviroment containing all dependencies.\nAfterwards, You can run the test suite using\n\n```bash\npoetry run pytest\n```\n\nThis repository follows the [Conventional Commits](https://www.conventionalcommits.org/)\nstyle.\n',
    'author': 'Jochem Berends',
    'author_email': 'jberends@jbits.nl',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/jberends/fast-microservice',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.1,<4.0',
}


setup(**setup_kwargs)



from pathlib import Path
from typing import Optional

from starlette.config import Config
from starlette.datastructures import Secret

from fast_microservice.__about__ import __version__

package_root: Path = Path(__file__).parent.parent.parent / ".env"
config: Config = Config(package_root if package_root.exists() else None)

APP_NAME: str = "Latex docker microservice"
APP_VERSION: str = __version__

# Application Root. This is the directory where './app' is in.
APP_ROOT: Path = Path(__file__).parents[2]

API_PREFIX: str = config("API_PREFIX", cast=str, default="/api")

# Very simple Authentication with API KEY
API_KEY: Optional[Secret] = config("API_KEY", cast=Secret, default=None)
API_AUTHORIZATION_HEADER: str = config(
    "API_AUTHORIZATION_HEADER", cast=str, default="Token"
)

# Set to True to enable debug mode
DEBUG: bool = config("DEBUG", cast=bool, default=True)

# Sentry error logging
SENTRY_ENABLED: bool = config("SENTRY_ENABLED", cast=bool, default=False)
SENTRY_DSN: Optional[Secret] = config("SENTRY_DSN", cast=Secret, default=None)

# PDF latex settings
PDFLATEX_PATH: Path = config(
    "PDFLATEX_PATH", cast=Path, default=Path("/usr/bin/lualatex")
)
DEBUG_LOG_RENDERED_TEX: bool = config(
    "DEBUG_LOG_RENDERED_TEX", cast=bool, default=DEBUG
)


print(
    f"""
{package_root=}
{DEBUG=}
{SENTRY_ENABLED=}
{SENTRY_DSN=}

"""
)



from fastapi import APIRouter

from fast_microservice.settings.globals import DEBUG

router = APIRouter()


@router.get("/error", name="error")
def get_error():
    """Raise ZeroDivisionError for debugging purposes."""
    if DEBUG:
        raise ZeroDivisionError("This is a debugging feature.")



def MiddlewareWrapper(middleware):
    """
    Wrap another Middleware ensure sane behaviour of the SentryAsgiMiddleware.

    According to issue:
    https://github.com/getsentry/sentry-python/issues/947

    The SentryAsgiMiddleware and Starlette 0.13 are incompatible with each other
    in early december 2020. From the thread we took a workaround to harness
    sentry into providing correct behaviour.
    """

    async def wrapper(*args, **kwds):
        return await middleware(*args, **kwds)

    return wrapper
